@@ -611,7 +611,7 @@ class WizataDSAPIClient(ApiInterface):
             raise TypeError("Type not supported.")
 
     def query(self,
-              datapoints: list[str] = None,
+              datapoints: list = None,
               start: datetime = None,
               end: datetime = None,
               interval: int = None,
@@ -662,11 +662,11 @@ class WizataDSAPIClient(ApiInterface):
 
         request.set_aggregation(agg_method, interval)
 
-        if template is not None and twin is not None:
-            request.select_template(
-                template_key=template,
-                twin_hardware_id=twin
-            )
+        if twin is not None:
+            request.set_twin(twin)
+
+        if template is not None:
+            request.set_template(template)
 
         if filters is not None:
             request.filters = filters
@@ -692,7 +692,7 @@ class WizataDSAPIClient(ApiInterface):
 
     def batch_query(self,
                     step: timedelta,
-                    datapoints: list[str] = None,
+                    datapoints: list = None,
                     start: datetime = None,
                     end: datetime = None,
                     interval: int = None,
